@@ -1,6 +1,6 @@
 package App::GitGot::Command;
 BEGIN {
-  $App::GitGot::Command::VERSION = '0.9.2';
+  $App::GitGot::Command::VERSION = '0.2';
 }
 BEGIN {
   $App::GitGot::Command::AUTHORITY = 'cpan:GENEHACK';
@@ -11,7 +11,6 @@ use Moose;
 extends 'MooseX::App::Cmd::Command';
 use 5.010;
 
-use List::Util qw/ max /;
 use Storable qw/ dclone /;
 use Try::Tiny;
 use YAML qw/ DumpFile LoadFile /;
@@ -26,22 +25,6 @@ has 'all' => (
   traits        => [qw/ Getopt /],
 );
 
-has 'by_path' => (
-  is          => 'rw' ,
-  isa         => 'Bool' ,
-  cmd_aliases => 'p',
-  traits      => [qw/ Getopt /],
-);
-
-has 'color_scheme' => (
-  is            => 'rw',
-  isa           => 'Str',
-  documentation => 'name of color scheme to use',
-  default       => 'dark',
-  cmd_aliases   => 'c' ,
-  traits        => [qw/ Getopt /],
-);
-
 has 'configfile' => (
   is            => 'rw',
   isa           => 'Str',
@@ -51,15 +34,6 @@ has 'configfile' => (
   required      => 1,
 );
 
-has 'no_color' => (
-  is            => 'rw',
-  isa           => 'Bool',
-  documentation => 'do not use colored output',
-  default       => 0,
-  cmd_aliases   => 'C',
-  traits        => [qw/ Getopt /],
-);
-
 has 'quiet' => (
   is            => 'rw',
   isa           => 'Bool',
@@ -112,44 +86,13 @@ has 'full_repo_list' => (
   } ,
 );
 
-has 'outputter' => (
-  is => 'ro' ,
-  isa => 'App::GitGot::Outputter' ,
-  traits => [ qw/ NoGetopt / ] ,
-  lazy_build => 1 ,
-  handles => [
-    'error' ,
-    'warning' ,
-    'major_change' ,
-    'minor_change' ,
-  ] ,
-);
-
 sub execute {
   my( $self , $opt , $args ) = @_;
   $self->args( $args );
-
-  # set up colored output if we page thru less
-  # also exit pager immediately if <1 page of output
-  $ENV{LESS} = 'RF';
-
-  # don't catch any errors here; if this fails we just output stuff like
-  # normal and nobody is the wiser.
-  eval 'use IO::Page';
-
   $self->_execute($opt,$args);
 }
 
 
-sub max_length_of_an_active_repo_label {
-  my( $self ) = @_;
-
-  my $sort_key = $self->by_path ? 'path' : 'name';
-
-  return max ( map { length $_->$sort_key } $self->active_repos);
-}
-
-
 sub prompt_yn {
   my( $self , $message ) = @_;
   printf '%s [y/N]: ' , $message;
@@ -205,18 +148,15 @@ sub _build_full_repo_list {
 
   my $repo_count = 1;
 
-  my $sort_key = $self->by_path ? 'path' : 'name';
-
   my @parsed_config;
 
-  foreach my $entry ( sort { $a->{$sort_key} cmp $b->{$sort_key} } @$config ) {
+  foreach my $entry ( sort { $a->{name} cmp $b->{name} } @$config ) {
 
     # a completely empty entry is okay (this will happen when there's no
     # config at all...)
     keys %$entry or next;
 
     push @parsed_config , App::GitGot::Repo->new({
-      label => ( $self->by_path ) ? $entry->{path} : $entry->{name} ,
       entry => $entry ,
       count => $repo_count++ ,
     });
@@ -225,30 +165,6 @@ sub _build_full_repo_list {
   return \@parsed_config;
 }
 
-sub _build_outputter {
-  my $self = shift;
-
-  my $scheme = $self->color_scheme;
-
-  if ( $scheme =~ /^\+/ ) {
-    $scheme =~ s/^\+//;
-  }
-  else {
-    $scheme = "App::GitGot::Outputter::$scheme"
-  }
-
-  try {
-    eval "use $scheme";
-    die $@ if $@;
-  }
-  catch {
-    say "Failed to load color scheme '$scheme'.\nExitting now.\n";
-    exit(5);
-  };
-
-  return $scheme->new({ no_color => $self->no_color });
-}
-
 sub _expand_arg_list {
   my $args = shift;
 
@@ -268,6 +184,7 @@ sub _expand_arg_list {
   ## use critic
 }
 
+
 sub _read_config {
   my $file = shift;
 
@@ -285,22 +202,15 @@ sub _read_config {
 
 package App::GitGot::Repo;
 BEGIN {
-  $App::GitGot::Repo::VERSION = '0.9.2';
+  $App::GitGot::Repo::VERSION = '0.2';
 }
 BEGIN {
   $App::GitGot::Repo::AUTHORITY = 'cpan:GENEHACK';
 }
 use Moose;
+
 use 5.010;
-
 use namespace::autoclean;
-use Git::Wrapper;
-use Try::Tiny;
-
-has 'label' => (
-  is       => 'ro' ,
-  isa      => 'Str' ,
-);
 
 has 'name' => (
   is          => 'ro',
@@ -336,28 +246,6 @@ has 'type' => (
   required    => 1 ,
 );
 
-has '_wrapper' => (
-  is         => 'ro' ,
-  isa        => 'Git::Wrapper' ,
-  lazy_build => 1 ,
-  handles    => [ qw/
-                      cherry
-                      clone
-                      config
-                      pull
-                      remote
-                      status
-                      symbolic_ref
-                    / ] ,
-);
-
-sub _build__wrapper {
-  my $self = shift;
-
-  return Git::Wrapper->new( $self->path )
-    or die "Can't make Git::Wrapper";
-}
-
 sub BUILDARGS {
   my( $class , $args ) = @_;
 
@@ -378,7 +266,7 @@ sub BUILDARGS {
 
   $entry->{tags} //= '';
 
-  my $return = {
+  return {
     number => $count ,
     name   => $entry->{name} ,
     path   => $entry->{path} ,
@@ -386,45 +274,6 @@ sub BUILDARGS {
     type   => $entry->{type} ,
     tags   => $entry->{tags} ,
   };
-
-  $return->{label} = $args->{label} if $args->{label};
-
-  return $return;
-}
-
-sub current_branch {
-  my $self = shift;
-
-  my $branch;
-
-  try {
-    my( $branch ) = $self->symbolic_ref( 'HEAD' );
-    $branch =~ s|^refs/heads/||;
-  }
-  catch {
-    die $_ unless $_ && $_->isa('Git::Wrapper::Exception')
-      && $_->error eq "fatal: ref HEAD is not a symbolic ref\n"
-  };
-
-  return $branch;
-}
-
-sub current_remote_branch {
-  my( $self ) = shift;
-
-  my $remote;
-
-  if ( my $branch = $self->current_branch ) {
-    try {
-      ( $remote ) = $self->config( "branch.$branch.remote" );
-    }
-    catch {
-      ## not the most informative return....
-      return 0 if $_ && $_->isa('Git::Wrapper::Exception') && $_->{status} eq '1';
-    };
-  }
-
-  return $remote;
 }
 
 sub in_writable_format {
@@ -453,14 +302,10 @@ App::GitGot::Command - Base class for App::GitGot commands
 
 =head1 VERSION
 
-version 0.9.2
+version 0.2
 
 =head1 METHODS
 
-=head2 max_length_of_an_active_repo_label
-
-Returns the length of the longest name in the active repo list.
-
 =head2 prompt_yn
 
 Takes a message argument and uses it to prompt for a yes/no response.
