@@ -1,6 +1,6 @@
 package App::GitGot::Command::add;
 BEGIN {
-  $App::GitGot::Command::add::VERSION = '0.9.2';
+  $App::GitGot::Command::add::VERSION = '0.2';
 }
 BEGIN {
   $App::GitGot::Command::add::AUTHORITY = 'cpan:GENEHACK';
@@ -13,7 +13,6 @@ use 5.010;
 
 use Config::INI::Reader;
 use Cwd;
-use File::Basename;
 use Term::ReadLine;
 
 has 'defaults' => (
@@ -49,13 +48,10 @@ sub _build_new_entry_from_user_input {
   }
 
   if ( $self->defaults ) {
-    my $cwd = getcwd
-      or die "ERROR: Couldn't determine path";
-    $name //= basename getcwd;
     die "ERROR: Couldn't determine name"      unless $name;
-    $repo //= '';
+    die "ERROR: Couldn't determine repo path" unless $repo;
     die "ERROR: Couldn't determine repo type" unless $type;
-    $path = $cwd;
+    $path = getcwd or die "ERROR: Couldn't determine path";
   }
   else {
     my $term = Term::ReadLine->new('gitgot');
@@ -118,7 +114,7 @@ App::GitGot::Command::add - add a new repo to your config
 
 =head1 VERSION
 
-version 0.9.2
+version 0.2
 
 =head1 AUTHOR
 
