@@ -1,6 +1,6 @@
 package App::GitGot::Command::remove;
 BEGIN {
-  $App::GitGot::Command::remove::VERSION = '0.9.2';
+  $App::GitGot::Command::remove::VERSION = '0.2';
 }
 BEGIN {
   $App::GitGot::Command::remove::AUTHORITY = 'cpan:GENEHACK';
@@ -36,7 +36,7 @@ sub _execute {
     my $number = $repo->number;
 
     if ( any { $number == $_->number } $self->active_repos ) {
-      my $name = $repo->label;
+      my $name = $repo->name;
 
       if ( $self->force or $self->prompt_yn( "got rm: remove '$name'?" )) {
         say "Removed repo '$name'" if $self->verbose;
@@ -61,7 +61,7 @@ App::GitGot::Command::remove - remove a managed repository from your config
 
 =head1 VERSION
 
-version 0.9.2
+version 0.2
 
 =head1 AUTHOR
 
