@@ -1,6 +1,6 @@
 package App::GitGot::Command::update;
 BEGIN {
-  $App::GitGot::Command::update::VERSION = '0.9.2';
+  $App::GitGot::Command::update::VERSION = '0.2';
 }
 BEGIN {
   $App::GitGot::Command::update::AUTHORITY = 'cpan:GENEHACK';
@@ -11,32 +11,26 @@ use Moose;
 extends 'App::GitGot::Command';
 use 5.010;
 
-use File::Path 2.08 qw/ make_path /;
-use Term::ANSIColor;
-use Try::Tiny;
+use Capture::Tiny qw/ capture /;
 
 sub command_names { qw/ update up / }
 
 sub _execute {
   my ( $self, $opt, $args ) = @_;
 
-  my $max_len = $self->max_length_of_an_active_repo_label;
-
  REPO: for my $repo ( $self->active_repos ) {
     next REPO unless $repo->repo;
 
     my $name = $repo->name;
 
-    my $msg = sprintf "%3d) %-${max_len}s  : ", $repo->number, $repo->label;
+    my $msg = sprintf "%3d) %-25s : ", $repo->number, $repo->name;
 
     my ( $status, $fxn );
 
     given ( $repo->type ) {
       when ('git') { $fxn = '_git_update' }
       ### FIXME      when( 'svn' ) { $fxn = 'svn_update' }
-      default {
-        $status = $self->error("ERROR: repo type '$_' not supported");
-      }
+      default { $status = "ERROR: repo type '$_' not supported" }
     }
 
     $status = $self->$fxn($repo) if ($fxn);
@@ -51,34 +45,38 @@ sub _git_update {
   my ( $self, $entry ) = @_
     or die "Need entry";
 
+  my $path = $entry->{path};
+
   my $msg = '';
 
-  my $path = $entry->path;
-
   if ( !-d $path ) {
-    make_path $path;
+    my $repo = $entry->{repo};
 
-    try {
-      $entry->clone( $entry->repo , './' );
-      $msg .= $self->major_change('Checked out');
+    my ( $o, $e ) = capture { system("git clone $repo $path") };
+
+    if ( $e =~ /\S/ ) {
+      $msg .= "ERROR: $e";
+    }
+    else {
+      $msg .= 'Checked out';
     }
-    catch { $msg .= $self->error('ERROR') . "\n$_" };
   }
   elsif ( -d "$path/.git" ) {
-    try {
-      my @o = $entry->pull;
-      if ( $o[0] eq 'Already up-to-date.' ) {
-        $msg .= $self->minor_change('Up to date') unless $self->quiet;
-      }
-      else {
-        $msg .= $self->major_change('Updated');
-        $msg .= "\n" . join("\n",@o) unless $self->quiet;
-      }
+    my ( $o, $e ) = capture { system("cd $path && git pull") };
+
+    if ( $o =~ /^Already up-to-date/m and !$e ) {
+      $msg .= 'Up to date' unless $self->quiet;
     }
+    elsif ( $e =~ /\S/ ) {
+      $msg .= 'ERROR';
+    }
+    else {
+      $msg .= 'Updated';
+    }
+
+    return ( $self->verbose ) ? "$msg\n$o$e" : $msg;
   }
-  catch { $msg .= $self->error('ERROR') . "\n$_" };
 
-  return $msg;
 }
 
 1;
@@ -92,7 +90,7 @@ App::GitGot::Command::update - update managed repositories
 
 =head1 VERSION
 
-version 0.9.2
+version 0.2
 
 =head1 AUTHOR
 
